[Python-checkins] gh-65496: Correct wording on csv's skipinitialspace argument (#96170)

JelleZijlstra webhook-mailer at python.org
Fri Oct 7 14:15:42 EDT 2022


https://github.com/python/cpython/commit/676d8ef3806758bcd1d3fd84a746c8a9b64480d0
commit: 676d8ef3806758bcd1d3fd84a746c8a9b64480d0
branch: main
author: Stanley <46876382+slateny at users.noreply.github.com>
committer: JelleZijlstra <jelle.zijlstra at gmail.com>
date: 2022-10-07T11:15:34-07:00
summary:

gh-65496: Correct wording on csv's skipinitialspace argument (#96170)

files:
M Doc/library/csv.rst
M Lib/test/test_csv.py
M Modules/_csv.c

diff --git a/Doc/library/csv.rst b/Doc/library/csv.rst
index 0cab95e1500a..41f11505aa10 100644
--- a/Doc/library/csv.rst
+++ b/Doc/library/csv.rst
@@ -420,7 +420,7 @@ Dialects support the following attributes:
 
 .. attribute:: Dialect.skipinitialspace
 
-   When :const:`True`, whitespace immediately following the *delimiter* is ignored.
+   When :const:`True`, spaces immediately following the *delimiter* are ignored.
    The default is :const:`False`.
 
 
diff --git a/Lib/test/test_csv.py b/Lib/test/test_csv.py
index a2b00430c7dd..d64bff13a44e 100644
--- a/Lib/test/test_csv.py
+++ b/Lib/test/test_csv.py
@@ -362,6 +362,11 @@ def test_read_quoting(self):
         self._read_test(['1,@,3,@,5'], [['1', ',3,', '5']], quotechar='@')
         self._read_test(['1,\0,3,\0,5'], [['1', ',3,', '5']], quotechar='\0')
 
+    def test_read_skipinitialspace(self):
+        self._read_test(['no space, space,  spaces,\ttab'],
+                        [['no space', 'space', 'spaces', '\ttab']],
+                        skipinitialspace=True)
+
     def test_read_bigfield(self):
         # This exercises the buffer realloc functionality and field size
         # limits.
diff --git a/Modules/_csv.c b/Modules/_csv.c
index d34d0a1296ae..25bf86f78e8f 100644
--- a/Modules/_csv.c
+++ b/Modules/_csv.c
@@ -704,7 +704,7 @@ parse_process_char(ReaderObj *self, _csvstate *module_state, Py_UCS4 c)
             self->state = ESCAPED_CHAR;
         }
         else if (c == ' ' && dialect->skipinitialspace)
             /* ignore space at start of field */
             ;
         else if (c == dialect->delimiter) {
             /* save empty field */
@@ -1647,9 +1647,9 @@ PyDoc_STRVAR(csv_module_doc,
 "        quoting character.  It defaults to '\"'.\n"
 "    * delimiter - specifies a one-character string to use as the\n"
 "        field separator.  It defaults to ','.\n"
-"    * skipinitialspace - specifies how to interpret whitespace which\n"
-"        immediately follows a delimiter.  It defaults to False, which\n"
-"        means that whitespace immediately following a delimiter is part\n"
+"    * skipinitialspace - specifies how to interpret spaces which\n"
+"        immediately follow a delimiter.  It defaults to False, which\n"
+"        means that spaces immediately following a delimiter is part\n"
 "        of the following field.\n"
 "    * lineterminator -  specifies the character sequence which should\n"
 "        terminate rows.\n"
@@ -704,7 +704,7 @@ parse_process_char(ReaderObj *self, _csvstate *module_state, Py_UCS4 c)
         }
         else if (c == ' ' && dialect->skipinitialspace)
-            /* ignore space at start of field */
+            /* ignore spaces at start of field */
             ;
         else if (c == dialect->delimiter) {



More information about the Python-checkins mailing list